# LearnRL a python library to learn and use reinforcement learning
# Copyright (C) 2020 Mathïs FEDERICO <https://www.gnu.org/licenses/>

from learnrl.environments.single_agents import RdNimEnv, CatchEnv
from learnrl.environments.multi_agents import CrossesAndNoughtsEnv

# Import basic gym envs
from gym.envs.algorithmic import *
from gym.envs.box2d import *
from gym.envs.classic_control import *
from gym.envs.toy_text import *

